@@ -29,7 +29,7 @@ class MainWindow : public KXmlGuiWindow
 {
     Q_OBJECT
 public:
-    MainWindow(QWidget *parent = 0);
+    explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
 private slots:
